<?php
/**
 * Makena 404 Page functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
* Add 404 Page Section
*/
function makena_error_page_customize_register( $wp_customize ) {
	$wp_customize->add_section(
		'makena_error_page_section',
		array(
			'title'       => esc_html__( '404 Page', 'makena' ),
			'capability'  => 'edit_theme_options',
			'panel' => 'makena_theme_options',
			'priority'   => 40,
		)
	);
	
	// Add 404 Page Container Title
	$wp_customize->add_setting(
		'makena_error_page_container_title',
		array(
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_error_page_container_title',
        array(
            'label'          => esc_html__( '404 Page Container Title', 'makena' ),
            'section'        => 'makena_error_page_section',
            'settings'       => 'makena_error_page_container_title',
            'type'           => 'text',
            )
        )
	);
	
	// Add 404 Page Content
	$wp_customize->add_setting(
		'makena_error_page_content',
		array(
		    'sanitize_callback' => 'force_balance_tags',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_error_page_content',
        array(
            'label'          => esc_html__( '404 Page Content', 'makena' ),
            'section'        => 'makena_error_page_section',
            'settings'       => 'makena_error_page_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add 404 Page Background Image
	$wp_customize->add_setting( 'makena_error_page_background_image',
		array(
			'default' => get_template_directory_uri().'/images/404.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'makena_error_page_background_image',
			array(
				'label'   	 => esc_html__( 'Featured Box Image 1', 'makena' ),
				'section' 	 => 'makena_error_page_section',
				'settings'   => 'makena_error_page_background_image',
			) 
		)
	);
	
}
add_action( 'customize_register', 'makena_error_page_customize_register' ); 

/**
 * Sets the backgorund image for the error_page
 */
function makena_error_page_customize_css() {
?>
    <style type="text/css">
        .errorPage{ 
            background-image: url('<?php echo get_theme_mod( "makena_error_page_background_image" );?>');
            -webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-position: center center;
        }
        .errorPage:before {
    		content: '';
    		position: absolute;
    		top: 0;
   	 		right: 0;
    		left: 0;
    		bottom: 0;
    		background: rgba(255,255,255,0.6);
	}
    </style>
<?php
}
add_action( 'wp_head', 'makena_error_page_customize_css');
