<?php
/**
 * Makena Banner Ads functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
* Add Front Page Banner Box Section
*/
function makena_banner_customize_register( $wp_customize ) {
	$wp_customize->add_section(
		'makena_banner_section',
		array(
			'title'       => esc_html__( 'Banner Ads', 'makena' ),
			'capability'  => 'edit_theme_options',
			'panel' => 'makena_theme_options',
			'priority'   => 20,
		)
	);
	
	// Add Banner Box 1 Image
	$wp_customize->add_setting( 'makena_banner1_image',
		array(
			'default' => get_template_directory_uri().'/images/1.jpeg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'makena_banner1_image',
			array(
				'label'   	 => esc_html__( 'Banner 1 Image', 'makena' ),
				'section' 	 => 'makena_banner_section',
				'settings'   => 'makena_banner1_image',
			) 
		)
	);
	
	// Add Banner Box 1 Title
	$wp_customize->add_setting(
		'makena_banner1_title',
		array(
		    'default'           => esc_html__( 'Add Your Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner1_title',
        array(
            'label'          => __( 'Banner 1 Title', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner1_title',
            'type'           => 'text',
            )
        )
	);
	
	// Add Button Text
	$wp_customize->add_setting(
		'makena_banner1_button',
		array(
		    'default'           => esc_html__( 'Add Button Text', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner1_button',
        array(
            'label'          => esc_html__( 'Button Text', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner1_button',
            'type'           => 'text',
            )
        )
	);
	
	// Add Banner Box 1 Link
	$wp_customize->add_setting(
		'makena_banner1_link',
		array(
		    'default'           => __( 'Place Link here', 'makena' ),
		    'type' 				=> 'theme_mod',
		    'transport' 		=> '',
		    'sanitize_callback' => 'esc_url',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner1_link',
        array(
            'label'          => __( 'Banner 1 Link', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner1_link',
            'type'           => 'url',
            )
        )
	);
	
	// Add Banner Box 2 Image
	$wp_customize->add_setting( 'makena_banner2_image',
		array(
			'default' => get_template_directory_uri().'/images/2.jpeg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'makena_banner2_image',
			array(
				'label'   	 => esc_html__( 'Banner 2 Image', 'makena' ),
				'section' 	 => 'makena_banner_section',
				'settings'   => 'makena_banner2_image',
			) 
		)
	);
	
	// Add Banner Box 2 Title
	$wp_customize->add_setting(
		'makena_banner2_title',
		array(
		    'default'           => esc_html__( 'Add Your Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner2_title',
        array(
            'label'          => esc_html__( 'Banner 2 Title', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner2_title',
            'type'           => 'text',
            )
        )
	);
	
	// Add Button Text
	$wp_customize->add_setting(
		'makena_banner2_button',
		array(
		    'default'           => esc_html__( 'Button Text', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner2_button',
        array(
            'label'          => esc_html__( 'Button Text', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner2_button',
            'type'           => 'text',
            )
        )
	);
	
	// Add Banner Box 2 Link
	$wp_customize->add_setting(
		'makena_banner2_link',
		array(
		    'default'           => esc_html__( 'Place Link here', 'makena' ),
		    'type' 				=> 'theme_mod',
		    'transport' 		=> '',
		    'sanitize_callback' => 'esc_url',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_banner2_link',
        array(
            'label'          => esc_html__( 'Banner 2 Link', 'makena' ),
            'section'        => 'makena_banner_section',
            'settings'       => 'makena_banner2_link',
            'type'           => 'url',
            )
        )
	);
	
}
add_action( 'customize_register', 'makena_banner_customize_register' ); 

/**
 * Banner background images
 */
function makena_banner_ads_customize_css() {
?>
    <style type="text/css">
        .banner-left { 
            background-image: url('<?php echo get_theme_mod("makena_banner1_image"); ?>');
            background-repeat: no-repeat;
            -webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-position: center center;
			padding: 72px 0;
        }
        .banner-right { 
            background-image: url('<?php echo get_theme_mod("makena_banner2_image"); ?>');
            background-repeat: no-repeat;
            -webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-position: center center;
			padding: 72px 0;
        }
    </style>
<?php
}
add_action( 'wp_head', 'makena_banner_ads_customize_css');

/**
 * Displays Banner Ads on the Front Page
 */
function makena_display_banners() { ?>
<?php if ( get_theme_mod( 'makena_banner1_image' ) || get_theme_mod( 'makena_banner1_title' ) || get_theme_mod( 'makena_banner1_content' ) ||
		   get_theme_mod( 'makena_banner2_image' ) || get_theme_mod( 'makena_banner2_title' ) || get_theme_mod( 'makena_banner2_content' ) ) : ?>
			
			<div class="col-6 banners">
  				<div class="banner-left">
					<div class="banner-content">
						<h3 class="banner-title"><?php echo get_theme_mod('makena_banner1_title'); ?></h3>
							<?php
								$makena_banner1_link = get_theme_mod( 'makena_banner1_link' );
								if ($makena_banner1_link) { ?>
  									<a href=" <?php echo esc_url( $makena_banner1_link ); ?> "><span class="button"><?php echo get_theme_mod('makena_banner1_button'); ?></span></a>
							<?php } ?>
					</div>
				</div><!--/.banner-item -->
					
  				<div class="banner-right">
					<div class="banner-content">
						<h3 class="banner-title"><?php echo get_theme_mod('makena_banner2_title'); ?></h3>
							<?php
								$makena_banner2_link = get_theme_mod( 'makena_banner2_link' );
								if ($makena_banner2_link) { ?>
  									<a href=" <?php echo esc_url( $makena_banner2_link ); ?> "><span class="button"><?php echo get_theme_mod('makena_banner2_button'); ?></span></a>
							<?php } ?>
					</div>	
				</div><!--/.banner-item -->
				
			</div><!--/.row.banners -->
			
				<?php else : //Nothing ?>

	<?php endif; ?>
 
<?php  
}