<?php
/**
 * Makena Layout Options Customizer functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
 * Adds Layout Options section and sidebar position setting.
 *
 * @param WP_Customize_Manager $wp_customize The Customizer object.
 */
function makena_layout_customize_register( $wp_customize ) {

		// Header Options
		
		// Add Header options section.
		$wp_customize->add_section( 'makena_header_options', array(
			'title'    => esc_html__( 'Header Options', 'makena' ),
			'panel' => 'makena_theme_options',
			'priority'   => 15,
		) );
		 
		// Display/hide slider
		$wp_customize->add_setting( 'makena_display_header_slider', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_header_slider', array(
			'label'    	=> esc_html__( 'Disable header slider', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_header_options',
  			'description' => __( 'Check to hide slider.' ),
		) );
		
		// Display/hide useful links
		$wp_customize->add_setting( 'makena_display_useful_links', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_useful_links', array(
			'label'    	=> esc_html__( 'Disable useful links', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_header_options',
  			'description' => __( 'Check to hide useful links.' ),
		) );
		
		// Display Header Image instead of Slider
		$wp_customize->add_setting( 'makena_display_hero_image', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_hero_image', array(
			'label'    	=> esc_html__( 'Display Hero Image instead of Slider', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_header_options',
  			'description' => __( 'Check to display hero image in header.' ),
		) );
		
		// Display banners
		$wp_customize->add_setting( 'makena_display_banners', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_banners', array(
			'label'    	=> esc_html__( 'Disable banners', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_header_options',
  			'description' => __( 'Check to hide banners.' ),
		) );
		
		// Homepage Options
		
		// Add Homepage options section.
		$wp_customize->add_section( 'makena_homepage_options', array(
			'title'    => esc_html__( 'Homepage Options', 'makena' ),
			'panel' => 'makena_theme_options',
			'priority'   => 15,
		) );
		
		// Display Featured Boxes
		$wp_customize->add_setting( 'makena_display_featuredbox', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_featuredbox', array(
			'label'    	=> esc_html__( 'Disable Featured Content Boxes', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide featured boxes.' ),
		) );
		
		 // Add Latest Shop Entries Section Title
		$wp_customize->add_setting(
			'makena_shop_entries_section_title', array(
		    'default'           => esc_html__( 'Add Latest Shop Entries Section Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_shop_entries_section_title', array(
            'label'          => esc_html__( 'Latest Shop Entries Section Title', 'makena' ),
            'section'  		 => 'makena_homepage_options',
            'settings'       => 'makena_shop_entries_section_title',
            'type'           => 'text',
        ) ) );
        
         // Add featured shop entries section title
		$wp_customize->add_setting(
			'makena_featured_shop_entries_section_title', array(
		    'default'           => esc_html__( 'Add featured shop entries section title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_featured_shop_entries_section_title', array(
            'label'          => esc_html__( 'Shop entries section title', 'makena' ),
            'section'  		 => 'makena_homepage_options',
            'settings'       => 'makena_featured_shop_entries_section_title',
            'type'           => 'text',
        ) ) );
            
        // Add archive link text
		$wp_customize->add_setting(
			'makena_se_archive_link_text', array(
		    'default'           => esc_html__( 'Add archive link text', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_se_archive_link_text', array(
            'label'          => esc_html__( 'Archive link text', 'makena' ),
            'section'  		 => 'makena_homepage_options',
            'settings'       => 'makena_se_archive_link_text',
            'type'           => 'text',
        ) ) );
            
		// Display shop entries
		$wp_customize->add_setting( 'makena_display_shop_entries', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_shop_entries', array(
			'label'    	=> esc_html__( 'Disable shop entries', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide shop entries.' ),
		) );
		
		// Add Brands Section Title
		$wp_customize->add_setting(
			'makena_brands_section_title', array(
		    'default'           => esc_html__( 'Add Brands Section Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_brands_section_title', array(
            'label'          => esc_html__( 'Brands Section Title', 'makena' ),
            'section'  		 => 'makena_homepage_options',
            'settings'       => 'makena_brands_section_title',
            'type'           => 'text',
            ) ) );
            
		// Display Featured Brands
		$wp_customize->add_setting( 'makena_display_featured_brands', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_featured_brands', array(
			'label'    	=> esc_html__( 'Disable Featured Brands', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide featured brands.' ),
		) );
		
		// Add Blog Posts Section Title
		$wp_customize->add_setting(
			'makena_blogposts_section_title', array(
		    'default'           => esc_html__( 'Add Blog Entries Section Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_blogposts_section_title', array(
            'label'          => esc_html__( 'Blog Posts Section Title', 'makena' ),
            'section'  		 => 'makena_homepage_options',
            'settings'       => 'makena_blogposts_section_title',
            'type'           => 'text',
            ) ) );
            
        // Display Blog posts
		$wp_customize->add_setting( 'makena_display_blog_posts', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_blog_posts', array(
			'label'    	=> esc_html__( 'Disable Blog Posts Section', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide blog posts.' ),
		) );
		
		// Display Newsletter
		$wp_customize->add_setting( 'makena_display_newsletter', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_newsletter', array(
			'label'    	=> esc_html__( 'Disable Newsletter Section', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide newsletter.' ),
		) );
		
		// Display Testimonials
		$wp_customize->add_setting( 'makena_display_testimonials', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_testimonials', array(
			'label'    	=> esc_html__( 'Disable Testimonials Section', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_homepage_options',
  			'description' => __( 'Check to hide testimonials.' ),
		) );

		
		// Blog Page
		
		// Add Blog Page options
		$wp_customize->add_section( 'makena_blog_options', array(
			'title'    => esc_html__( 'Blog Page Options', 'makena' ),
			'panel' => 'makena_theme_options',
			'priority'   => 30,
		) );
		
		// Add Sidebar Position Switch
		$wp_customize->add_setting( 'sidebar_position', array(
		'default'           => 'right',
		'sanitize_callback' => 'makena_sanitize_radio',
		'transport'         => 'refresh',
		) );
		$wp_customize->add_control( 'sidebar_position', array(
			'label'    => esc_html__( 'Sidebar Position', 'makena' ),
			'section'  => 'makena_blog_options',
			'type'     => 'radio',
			'priority' => 1,
			'choices'  => array(
			'left'   => esc_html__( 'Left Sidebar', 'makena' ),
			'right'  => esc_html__( 'Right Sidebar', 'makena' ),
		),
		) );
		
		// Add Blog Layout Options
		$wp_customize->add_setting( 'makena_blog_layout', array(
			'default'           => 'classic',
			'sanitize_callback' => 'makena_sanitize_radio',
			'transport'         => 'refresh',
		) );
		$wp_customize->add_control( 'makena_blog_layout', array(
			'label'    	=> esc_html__( 'Blog Page Layout', 'makena' ),
			'section'  	=> 'makena_blog_options',
			'type'     	=> 'radio',
			'priority' 	=> 1,
			'choices'  	=> array(
			'list'  	=> esc_html__( 'List', 'makena' ),
			'classic'  	=> esc_html__( 'Standard', 'makena' ),
		),
		) );
		
		// Add custom excerpt length on blog page
		$wp_customize->add_setting( 'makena_excerpt_length', array(
			'default'           => 20,
			'sanitize_callback' => 'absint',
		) );
		$wp_customize->add_control( 'makena_excerpt_length', array(
			'type'        	=> 'number',
			'input_attrs' 	=> array(
			'min'  			=> 10,
			'step' 			=> 1,
			),
			'section'  		=> 'makena_blog_options',
			'label'       	=> esc_html__( 'Generate custom excerpt length', 'makena' ),
		) );
		
		// Single Post Options
		
		// Add single posts options
		$wp_customize->add_section( 'makena_single_options', array(
			'title'    => esc_html__( 'Single Post Options', 'makena' ),
			'panel' => 'makena_theme_options',
			'priority'   => 35,
		) );
		
		// Display Comments Link
		$wp_customize->add_setting( 'makena_comments_link', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_comments_link', array(
			'label'    	=> esc_html__( 'Hide Comments Link', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_single_options',
  			'description' => __( 'Check to hide comments link.' ),
		) );
		
		// Add Giveaway Box Title
		$wp_customize->add_setting(
			'giveaway_entry_title', array(
		    'default'           => esc_html__( 'Add Giveaway Box Title', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'giveaway_entry_title', array(
            'label'          => esc_html__( 'Giveaway Box Title', 'makena' ),
            'section'  		 => 'makena_single_options',
            'settings'       => 'giveaway_entry_title',
            'type'           => 'text',
        ) ) );

		// Add Giveaway Button Text
		$wp_customize->add_setting(
			'makena_giveaway_link_text', array(
		    'default'           => esc_html__( 'Giveaway Box Text', 'makena' ),
		    'sanitize_callback' => 'sanitize_text_field',
		    'transport'         => 'refresh',
			) );

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_giveaway_link_text', array(
            'label'          => esc_html__( 'Giveaway Button Text', 'makena' ),
            'section'  		 => 'makena_single_options',
            'settings'       => 'makena_giveaway_link_text',
            'type'           => 'text',
        ) ) );
        
        // Footer Options
        
		// Add footer options
		$wp_customize->add_section( 'makena_footer_options', array(
			'title'    => esc_html__( 'Footer Options', 'makena' ),
			'panel' => 'makena_theme_options',
			'priority'   => 35,
		) );
		
		// Display Widget Area
		$wp_customize->add_setting( 'makena_display_widget_area', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_widget_area', array(
			'label'    	=> esc_html__( 'Disable Widget Area', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_footer_options',
  			'description' => __( 'Check to hide widget area.' ),
		) );
		
		// Display Designer Credits
		$wp_customize->add_setting( 'makena_display_designer_credits', array(
			'default'           => '',
  			'capability' 		=> 'edit_theme_options',
  			'sanitize_callback' => 'makena_sanitize_checkbox',
		) );
		$wp_customize->add_control( 'makena_display_designer_credits', array(
			'label'    	=> esc_html__( 'Disable Designer Credits', 'makena' ),
  			'type' 		=> 'checkbox',
  			'section'  	=> 'makena_footer_options',
  			'description' => __( 'Check to hide designer credits.' ),
		) );
		
		
}
add_action( 'customize_register', 'makena_layout_customize_register' );

function makena_layout_customize_css() { ?>

	<?php 
	
	// Display Header Slider
	if ( !get_theme_mod( 'makena_display_header_slider' ) ) { // false ?>
    <style> .sliderWrap { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_header_slider' ) == 1 ) { // true ?>
    <style> .sliderWrap { display: none; } </style> <?php }
    
    // Display Useful Links
	if ( !get_theme_mod( 'makena_display_useful_links' ) ) { // false ?>
    <style> .useful-links { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_useful_links' ) == 1 ) { // true ?>
    <style> .useful-links { display: none; } </style> <?php }
    
    // Display Ads Banners
	if ( !get_theme_mod( 'makena_display_banners' ) ) { // false ?>
    <style> .gridWrap.style-1 { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_banners' ) == 1 ) { // true ?>
    <style> .gridWrap.style-1 { display: none; } </style> <?php }
    
    // Display Ads Banners
	if ( !get_theme_mod( 'makena_display_featuredbox' ) ) { // false ?>
    <style> .gridWrap.style-2 { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_featuredbox' ) == 1 ) { // true ?>
    <style> .gridWrap.style-2 { display: none; } </style> <?php }
    
    // Display Shop Entries
	if ( !get_theme_mod( 'makena_display_shop_entries' ) ) { // false ?>
    <style> .shop-entries { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_shop_entries' ) == 1 ) { // true ?>
    <style> .shop-entries { display: none; } </style> <?php }

    // Display Blog Entries
	if ( !get_theme_mod( 'makena_display_blog_posts' ) ) { // false ?>
    <style> .latest-blogposts { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_blog_posts' ) == 1 ) { // true ?>
    <style> .latest-blogposts { display: none; } </style> <?php }

    // Display Featured Brands
	if ( !get_theme_mod( 'makena_display_featured_brands' ) ) { // false ?>
    <style> .gridWrap.brands { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_featured_brands' ) == 1 ) { // true ?>
    <style> .gridWrap.brands { display: none; } </style> <?php }

    // Display Newsletter
	if ( !get_theme_mod( 'makena_display_newsletter' ) ) { // false ?>
    <style> .newsletterWrap { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_newsletter' ) == 1 ) { // true ?>
    <style> .newsletterWrap { display: none; } </style> <?php }

    // Display Testimonials
	if ( !get_theme_mod( 'makena_display_testimonials' ) ) { // false ?>
    <style> .gridWrap.testimonials { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_testimonials' ) == 1 ) { // true ?>
    <style> .gridWrap.testimonials { display: none; } </style> <?php }

    // Display Widget Area
	if ( !get_theme_mod( 'makena_display_widget_area' ) ) { // false ?>
    <style> #footer-widgets.widget-area.three { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_widget_area' ) == 1 ) { // true ?>
    <style> #footer-widgets.widget-area.three { display: none; } </style> <?php }
    
     // Display Designer Credits
	if ( !get_theme_mod( 'makena_display_designer_credits' ) ) { // false ?>
    <style> .site-info { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_display_designer_credits' ) == 1 ) { // true ?>
    <style> .site-info { display: none; } .makena_copyright {width:100%; float: left; text-align: center;}</style> <?php }

     // Display Comments Link
	if ( !get_theme_mod( 'makena_comments_link' ) ) { // false ?>
    <style> .comments-link { display: block; } </style> <?php }

	if ( get_theme_mod( 'makena_comments_link' ) == 1 ) { // true ?>
    <style> .comments-link { display: none; } </style> <?php }
    
	?>
	
    <?php
}
add_action( 'wp_head', 'makena_layout_customize_css');
