<?php
/**
 * Newsletter Section functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
* Add Front Page Newsletter Section
*/
function makena_newsletter_customize_register( $wp_customize ) {
	$wp_customize->add_section(
		'makena_newsletter_section',
		array(
			'title'       => esc_html__( 'Newsletter', 'makena' ),
			'capability'  => 'edit_theme_options',
			'panel' => 'makena_theme_options',
			'priority'   => 45,
		)
	);
	
	// Add Newsletter Container Title
	$wp_customize->add_setting(
		'makena_newsletter_container_title',
		array(
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_newsletter_container_title',
        array(
            'label'          => esc_html__( 'Newsletter Section Title', 'makena' ),
            'section'        => 'makena_newsletter_section',
            'settings'       => 'makena_newsletter_container_title',
            'type'           => 'text',
            )
        )
	);
	
	// Add Newsletter Content
	$wp_customize->add_setting(
		'makena_newsletter_content',
		array(
		    'sanitize_callback' => 'force_balance_tags',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'makena_newsletter_content',
        array(
            'label'          => esc_html__( 'Newsletter Content', 'makena' ),
            'section'        => 'makena_newsletter_section',
            'settings'       => 'makena_newsletter_content',
            'type'           => 'textarea',
            )
        )
	);
	
	// Add Newsletter Background Image
	$wp_customize->add_setting( 'makena_newsletter_background_image',
		array(
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'makena_newsletter_background_image',
			array(
				'label'   	 => esc_html__( ' Newsletter Background Image', 'makena' ),
				'section' 	 => 'makena_newsletter_section',
				'settings'   => 'makena_newsletter_background_image',
			) 
		)
	);
	
}
add_action( 'customize_register', 'makena_newsletter_customize_register' ); 

/**
 * Sets the backgorund image for the newsletter section
 */
function makena_newsletter_customize_css() {
?>
    <style type="text/css">
       .newsletterWrap { 
            background-image: url('<?php echo get_theme_mod( "makena_newsletter_background_image" );?>');
            background-repeat: no-repeat;
            -webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-position: center center;
        }
       .newsletterWrap:before {
    		content: '';
    		position: absolute;
    		top: 0;
   	 		right: 0;
    		left: 0;
    		bottom: 0;
    		background: rgba(255,255,255,0.6);
		}
    </style>
<?php
}
add_action( 'wp_head', 'makena_newsletter_customize_css');

/**
 * Displays Newsletter Signup on the Front Page
 */
function makena_newsletter() { ?>
<?php if ( 	get_theme_mod( 'makena_newsletter_container_title' ) || get_theme_mod( 'makena_newsletter_content' ) ||	get_theme_mod( 'makena_newsletter_background_image' ) ) : ?>
		
		<div class="col-6 newsletter">
			<?php
				$newsletter_container_title = get_theme_mod('makena_newsletter_container_title');
					if ( $newsletter_container_title ) { ?>
					<div class="col-3">
						<div class="content">
   							<header class="entry-header">
								<h2 class="entry-title"><?php echo get_theme_mod('makena_newsletter_container_title'); ?></h2>
							</header>
   							<div class="entry-content">
								<?php echo get_theme_mod('makena_newsletter_content'); ?>
							</div>
						</div>
					</div>
					
					<div class="col-3">
						<div class="makena-newsletter">
							<div id="mc_embed_signup">
								<?php if( function_exists( 'mc4wp_show_form' ) ) { ?>
									<?php mc4wp_show_form(); ?>
								<?php } ?>
							</div>
						</div>
					</div>
				<?php 
			} ?>
		</div>
		<?php else : //Nothing ?>
<?php endif; ?>
 
<?php  
}
