<?php
/**
 * Makena Theme Colors Customizer functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
  * Change text and title color, background and button color
  *
  */
function makena_colors_customize_register( $wp_customize ) {

		// Add Theme Colors Section
		$wp_customize->add_section( 'makena_theme_colors' , array(
    		'title'      => esc_html__( 'Theme Colors', 'makena' ),
    		'priority'   => 30,
    		'panel' => 'makena_theme_options',
		) );

		// General title color
		$wp_customize->add_setting( 'general_title_color' , array(
    		'default'   => '#000000',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_title_color', array(
			'label'      => esc_html__( 'Title Color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'general_title_color',
			'description' => __( 'Applies to all titles.' ),
		) ) );
		
		// General title hover color
		$wp_customize->add_setting( 'general_link_hover_color' , array(
    		'default'   => '#e6c200',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_link_hover_color', array(
			'label'      => esc_html__( 'Link hover color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'general_link_hover_color',
			'description' => __( 'Applies to all titles.' ),
		) ) );
 
 		// Useful links bar
		$wp_customize->add_setting( 'useful_links_bg_color' , array(
    		'default'   => '#fbfbfb',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'useful_links_bg_color', array(
			'label'      => esc_html__( 'Featured content box color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'useful_links_bg_color',
			'description' => __( 'Change background color.' ),
		) ) );

 		// Useful links text color
		$wp_customize->add_setting( 'useful_links_text_color' , array(
    		'default'   => '#000000',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'useful_links_text_color', array(
			'label'      => esc_html__( 'Useful links text color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'useful_links_text_color',
			'description' => __( 'Change text color.' ),
		) ) );
		
		// Slider caption background color
		$wp_customize->add_setting( 'flex_caption_color' , array(
    		'default'   => '#000000',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'flex_caption_color', array(
			'label'      => esc_html__( 'Slider Content Background Color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'flex_caption_color',
			'description' => __( 'Applies to header slider.' ),
		) ) );
		
		// Slider text color
		$wp_customize->add_setting( 'flex_title_color' , array(
    		'default'   => '#ffffff',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'flex_title_color', array(
			'label'      => esc_html__( 'Slider Title Color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'flex_title_color',
			'description' => __( 'Applies to header slider caption.' ),
		) ) );
		
		// General button color
		$wp_customize->add_setting( 'general_button_bg_color' , array(
    		'default'   => '#000000',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_button_bg_color', array(
			'label'      => esc_html__( 'Button color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'general_button_bg_color',
			'description' => __( 'Applies to all buttons and sidebar widget border.' ),
		) ) );

		// General button hover color
		$wp_customize->add_setting( 'general_button_hover_color' , array(
    		'default'   => '#e6c200',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_button_hover_color', array(
			'label'      => esc_html__( 'Button hover color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'general_button_hover_color',
			'description' => __( 'Applies to all buttons.' ),
		) ) );

		// General button text color
		$wp_customize->add_setting( 'general_button_text_color' , array(
    		'default'   => '#ffffff',
    		'transport' => 'refresh',
    		'sanitize_callback' => 'sanitize_hex_color'
		) );
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'general_button_text_color', array(
			'label'      => esc_html__( 'Banner text color', 'makena' ),
			'section'    => 'makena_theme_colors',
			'settings'   => 'general_button_text_color',
			'description' => __( 'Applies to all button text.' ),
		) ) );
}
add_action( 'customize_register', 'makena_colors_customize_register' );

function makena_theme_colors_customize_css() { ?>
	<style>
         
        /* Title color */ 
       	h1, h2, h3, h4, h5, h6, .entry-title, .entry-title a, .post-title a, .product-title a
         	{ color: <?php echo get_theme_mod('general_title_color', '#000000'); ?>; }
         	
        /* Link hover color */ 
       	a:hover, footer.entry-meta a:hover, .widget-area .widget a:hover, footer[role="contentinfo"] a:hover, .leave-reply:hover, .woocommerce-breadcrumb a:hover,
       	.related.products .woocommerce-loop-product__title:hover, .woocommerce-loop-product__title:hover, a.button.product_type_simple.add_to_cart_button.ajax_add_to_cart:hover	
         	{ color: <?php echo get_theme_mod('general_link_hover_color', '#e6c200'); ?>; }

        /* Copyright link color */ 
       	.makena_copyright a, .posted_in a, .tagged_as a, .woocommerce-info:before
         	{ color: <?php echo get_theme_mod('general_link_hover_color', '#e6c200'); ?> !important; }
        .woocommerce-info {border-top-color:<?php echo get_theme_mod('general_link_hover_color', '#e6c200'); ?>; }
         
        /* Useful links colors */ 
   		.useful-links, .col-6.featured-entries
         	{ background: <?php echo get_theme_mod('useful_links_bg_color', '#fbfbfb'); ?>;}
         	
   		.useful-links h3, .useful-links h3 a
        	{ color: <?php echo get_theme_mod('useful_links_text_color', '#000000'); ?>;}
         
        /* Slider caption background and text color */ 
       	.flex-caption, .flex-direction-nav .flex-next, .flex-direction-nav .flex-prev, .flex-control-paging li a.flex-active
        	{ background: <?php echo get_theme_mod('flex_caption_color', '#000000'); ?>;}
        	
       	.flex-caption h3, .flex-direction-nav a:before
        	{ color: <?php echo get_theme_mod('flex_title_color', '#ffffff'); ?>;}
         
        /* Banner button color */ 
       	span.button, a.moretag, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, 
       	.woocommerce .product .add_to_cart_button.button, .mc4wp-form-fields input[type="submit"], input#searchsubmit
        	{ background: <?php echo get_theme_mod('general_button_bg_color', '#000000'); ?>; border: 1px solid <?php echo get_theme_mod('general_button_bg_color', '#000000'); ?>;}
        	
        /* Banner button hover color */ 
       	span.button:hover, a.moretag:hover, .menu-toggle:hover, .menu-toggle:focus, button:hover, input[type="submit"]:hover, input[type="button"]:hover, input[type="reset"]:hover, 
       	article.post-password-required input[type="submit"]:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, 
       	.woocommerce input.button.alt:hover:hover, .woocommerce .product .add_to_cart_button.button:hover, .mc4wp-form-fields input[type="submit"]:hover, input#searchsubmit:hover
         	{ background: <?php echo get_theme_mod('general_button_hover_color', '#e6c200'); ?>; border: 1px solid <?php echo get_theme_mod('general_button_hover_color', '#e6c200'); ?>; }
         	
        /* Banner button text color */ 
        span.button, a.moretag, .widget.widget_cggbiography_widget .bio-user-btn a, .mc4wp-form-fields input[type="submit"], input#searchsubmit, .woocommerce button.button.alt
        	{ color: <?php echo get_theme_mod('general_button_text_color', '#ffffff'); ?>;}
         
        /* Widget border */
        .widget-area .widget
        { border: 3px solid <?php echo get_theme_mod('general_button_bg_color', '#000000'); ?>;}
         
    </style>
    <?php
}
add_action( 'wp_head', 'makena_theme_colors_customize_css');