<?php
/**
 * Makena Theme Options
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */

// Settings Page: Makena Headers
class makenaheaders_Settings_Page {

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'wph_create_settings' ) );
		add_action( 'admin_init', array( $this, 'wph_setup_sections' ) );
		add_action( 'admin_init', array( $this, 'wph_setup_fields' ) );
		add_action( 'admin_footer', array( $this, 'media_fields' ) );
		add_action( 'admin_enqueue_scripts', 'wp_enqueue_media' );
	}

	public function wph_create_settings() {
		$page_title = 'Makena Header Images';
		$menu_title = 'Shop Page';
		$capability = 'manage_options';
		$slug = 'makenaheaders';
		$callback = array($this, 'wph_settings_content');
		$icon = 'dashicons-format-image';
		$position = 10;
		add_menu_page($page_title, $menu_title, $capability, $slug, $callback, $icon, $position);
	}

	public function wph_settings_content() { ?>
		<div class="wrap">
			<h1>Makena Header Images</h1>
			<?php settings_errors(); ?>
			<form method="POST" action="options.php">
				<?php
					settings_fields( 'makenaheaders' );
					do_settings_sections( 'makenaheaders' );
					submit_button();
				?>
			</form>
		</div> <?php
	}

	public function wph_setup_sections() {
		add_settings_section( 'makenaheaders_section', 'Upload header image to your Shop page.', array(), 'makenaheaders' );
	}

	public function wph_setup_fields() {
		$fields = array(
			array(
				'label' => 'Shop Header Title',
				'id' => 'header_title_shop',
				'type' => 'text',
				'section' => 'makenaheaders_section',
				'desc' => 'Add a title to your shop page header.',
			),
			array(
				'label' => 'Shop Header Image',
				'id' => 'header_image_shop',
				'type' => 'media',
				'section' => 'makenaheaders_section',
				'returnvalue' => 'url',
				'desc' => 'Upload an image to your shop page header.',
			),
		);
		foreach( $fields as $field ){
			add_settings_field( $field['id'], $field['label'], array( $this, 'wph_field_callback' ), 'makenaheaders', $field['section'], $field );
			register_setting( 'makenaheaders', $field['id'] );
		}
	}

	public function wph_field_callback( $field ) {
		$value = get_option( $field['id'] );
		$placeholder = '';
		if ( isset($field['placeholder']) ) {
			$placeholder = $field['placeholder'];
		}
		switch ( $field['type'] ) {
				case 'media':
					$field_url = '';
					if ($value) {
						if ($field['returnvalue'] == 'url') {
							$field_url = $value;
						} else {
							$field_url = wp_get_attachment_url($value);
						}
					}
					printf(
						'<input style="display:none;" id="%s" name="%s" type="text" value="%s"  data-return="%s"><div id="preview%s" style="margin-right:10px;border:1px solid #e2e4e7;background-color:#fafafa;display:inline-block;width: 100px;height:100px;background-image:url(%s);background-size:cover;background-repeat:no-repeat;background-position:center;"></div><input style="width: 19%%;margin-right:5px;" class="button makenaheaders-media" id="%s_button" name="%s_button" type="button" value="Select" /><input style="width: 19%%;" class="button remove-media" id="%s_buttonremove" name="%s_buttonremove" type="button" value="Clear" />',
						$field['id'],
						$field['id'],
						$value,
						$field['returnvalue'],
						$field['id'],
						$field_url,
						$field['id'],
						$field['id'],
						$field['id'],
						$field['id']
					);
					break;
			default:
				printf( '<input name="%1$s" id="%1$s" type="%2$s" placeholder="%3$s" value="%4$s" />',
					$field['id'],
					$field['type'],
					$placeholder,
					$value
				);
		}
		if( isset($field['desc']) ) {
			if( $desc = $field['desc'] ) {
				printf( '<p class="description">%s </p>', $desc );
			}
		}
	}
	public function media_fields() {
		?><script>
			jQuery(document).ready(function($){
				if ( typeof wp.media !== 'undefined' ) {
					var _custom_media = true,
					_orig_send_attachment = wp.media.editor.send.attachment;
					$('.makenaheaders-media').click(function(e) {
						var send_attachment_bkp = wp.media.editor.send.attachment;
						var button = $(this);
						var id = button.attr('id').replace('_button', '');
						_custom_media = true;
							wp.media.editor.send.attachment = function(props, attachment){
							if ( _custom_media ) {
								if ($('input#' + id).data('return') == 'url') {
									$('input#' + id).val(attachment.url);
								} else {
									$('input#' + id).val(attachment.id);
								}
								$('div#preview'+id).css('background-image', 'url('+attachment.url+')');
							} else {
								return _orig_send_attachment.apply( this, [props, attachment] );
							};
						}
						wp.media.editor.open(button);
						return false;
					});
					$('.add_media').on('click', function(){
						_custom_media = false;
					});
					$('.remove-media').on('click', function(){
						var parent = $(this).parents('td');
						parent.find('input[type="text"]').val('');
						parent.find('div').css('background-image', 'url()');
					});
				}
			});
		</script><?php
	}

}
new makenaheaders_Settings_Page();

function cgg_header_image_css() {
?>
    <style type="text/css">
        .hero-image-container { 
            background-image: url('<?php echo get_option( "header_image_shop" ); ?>');
            background-repeat: no-repeat;
            -webkit-background-size: cover;
			-moz-background-size: cover;
			-o-background-size: cover;
			background-size: cover;
			background-position: center center;
			padding: 72px 0;
        }
        .hero-image-container:before{
    		content: '';
    		position: absolute;
    		top: 0;
   	 		right: 0;
    		left: 0;
    		bottom: 0;
    		background: rgba(0,0,0,0.4);
	}
    </style>
<?php
}
add_action( 'wp_head', 'cgg_header_image_css');

function cgg_header_image() { 

	if( is_post_type_archive('product') ) : ?>
		<div class="hero-image-container">
			<div class="containerContent site">
				<header class="entry-header">
					<h1 class="entry-title">
						<span><?php echo get_option( "header_title_shop" ); ?></span>
					</h1>
				</header>
			</div>
		</div>
	<?php endif; ?>
		
<?php } 