<?php
/**
 * Image Credit Metabox
 * Author: Chimene Gaspar
 * Description: Add an image and photographer credit to uploades images
 */
 
// Meta Box Class: Photo Details
class photodetailsMetabox {

	private $screen = array(
		'post',
		'product',
	);

	private $meta_fields = array(
		array(
			'label' => 'Photo by',
			'id' => 'photo_by',
			'type' => 'text',
		),
		array(
			'label' => 'Photo source',
			'id' => 'photo_source',
			'type' => 'url',
		),
	);

	public function __construct() {
		add_action( 'add_meta_boxes', array( $this, 'add_meta_boxes' ) );
		add_action( 'save_post', array( $this, 'save_fields' ) );
	}

	public function add_meta_boxes() {
		foreach ( $this->screen as $single_screen ) {
			add_meta_box(
				'photodetails',
				__( 'Photo Details', 'makena' ),
				array( $this, 'meta_box_callback' ),
				$single_screen,
				'advanced',
				'high'
			);
		}
	}

	public function meta_box_callback( $post ) {
		wp_nonce_field( 'photodetails_data', 'photodetails_nonce' );
		echo 'Add photographer and image source.';
		$this->field_generator( $post );
	}

	public function field_generator( $post ) {
		$output = '';
		foreach ( $this->meta_fields as $meta_field ) {
			$label = '<label for="' . $meta_field['id'] . '">' . $meta_field['label'] . '</label>';
			$meta_value = get_post_meta( $post->ID, $meta_field['id'], true );
			if ( empty( $meta_value ) ) {
				if ( isset( $meta_field['default'] ) ) {
					$meta_value = $meta_field['default'];
				}
			}
			switch ( $meta_field['type'] ) {
				default:
					$input = sprintf(
						'<input %s id="%s" name="%s" type="%s" value="%s">',
						$meta_field['type'] !== 'color' ? 'style="width: 100%"' : '',
						$meta_field['id'],
						$meta_field['id'],
						$meta_field['type'],
						$meta_value
					);
			}
			$output .= $this->format_rows( $label, $input );
		}
		echo '<table class="form-table"><tbody>' . $output . '</tbody></table>';
	}

	public function format_rows( $label, $input ) {
		return '<tr><th>'.$label.'</th><td>'.$input.'</td></tr>';
	}

	public function save_fields( $post_id ) {
		if ( ! isset( $_POST['photodetails_nonce'] ) )
			return $post_id;
		$nonce = $_POST['photodetails_nonce'];
		if ( !wp_verify_nonce( $nonce, 'photodetails_data' ) )
			return $post_id;
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )
			return $post_id;
		foreach ( $this->meta_fields as $meta_field ) {
			if ( isset( $_POST[ $meta_field['id'] ] ) ) {
				switch ( $meta_field['type'] ) {
					case 'email':
						$_POST[ $meta_field['id'] ] = sanitize_email( $_POST[ $meta_field['id'] ] );
						break;
					case 'text':
						$_POST[ $meta_field['id'] ] = sanitize_text_field( $_POST[ $meta_field['id'] ] );
						break;
				}
				update_post_meta( $post_id, $meta_field['id'], $_POST[ $meta_field['id'] ] );
			} else if ( $meta_field['type'] === 'checkbox' ) {
				update_post_meta( $post_id, $meta_field['id'], '0' );
			}
		}
	}
}

if (class_exists('photodetailsMetabox')) {
	new photodetailsMetabox;
};

/**
 * Display photo details
 */
 function photo_details_metabox() {
 
 	global $post;
 	
 	if ( get_post_meta( get_the_ID(), 'photo_by', true ) || ( get_post_meta( get_the_ID(), 'photo_source', true ) ) ):
 	
 	$photo_by = get_post_meta( $post->ID, 'photo_by', true );
  	$photo_source = get_post_meta( $post->ID, 'photo_source', true );
  	
  	if ( ! empty ( $photo_by ) || ( $photo_source ) ) { ?>
  			<div class="photo-details">
  				<?php if( !empty( $photo_by ) ) {
					echo '<span class="photoby">' .$photo_by. '</span>';
				} ?>
				
  				<?php if( !empty( $photo_source ) ) {
					echo '<a class="photo-url" target="_blank" href="'. esc_url( $photo_source ) .'">Source</a>';
				} ?>
  			</div>
 	<?php } 
 	 endif; 
}