<?php
/**
 * Testimonial custom post type and functionality
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
function create_testimonials_posttype() {
  $args = array(
    'labels' => array(
      'name' => __('Testimonials', 'makena' ),
      'singular_name' => __('Testimonials', 'makena' ),
      'all_items' => __('All Testimonials', 'makena' ),
      'add_new_item' => __('Add New Testimonial', 'makena' ),
      'edit_item' => __('Edit Testimonial', 'makena' ),
      'view_item' => __('View Testimonial', 'makena' )
    ),
    'public' => true,
    'has_archive' => false,
    'rewrite' => array('slug' => 'testimonials'),
    'show_ui' => true,
    'show_in_menu' => true,
    'show_in_nav_menus' => true,
    'capability_type' => 'page',
    'supports' => array('title', 'editor', 'thumbnail'),
    'exclude_from_search' => true,
    'menu_position' => 20,
    'menu_icon' => 'dashicons-format-status'
    );
  register_post_type('testimonials', $args);
}
add_action( 'init', 'create_testimonials_posttype');

function add_testimonials() {

	$screens = array( 'post', 'testimonials' );
	
	foreach ( $screens as $screen ) {
  		add_meta_box('testimonials', 'Testimonials', 'testimonialsCallBack', 'testimonials', 'normal', 'default' );
  	}
}
add_action('add_meta_boxes', 'add_testimonials');

function testimonialsCallBack($post) {
  wp_nonce_field( 'testimonials_meta_box', 'testimonials_nonce' );
 	global $post;
  	$name_value = get_post_meta( $post->ID, '_testimonials_name', true );
  	$company_value = get_post_meta( $post->ID, '_testimonials_company', true );
 
 	echo '<div style="padding:10px 0;">';
  	echo '<strong><label for="testimonials-name">'. 'Customer Name' .'</label></strong></br>';
  	echo '<input type="text" id="testimonials-name" name="testimonials_name" placeholder="Example" value="'.$name_value.'" size="25"/>';
 	echo '</div>';
 	echo '<div style="padding:10px 0;">';
  	echo '<strong><label for="testimonials-company">'. 'Customer Company' .'</label></strong></br>';
  	echo '<input type="text" id="testimonials-company" name="testimonials_company" placeholder="0231000000" value="'.$company_value.'" size="25"/>';
  	echo '</div>';

}

function save_testimonials( $post_id ) {

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
  		return;
	}
	
	if ( ! isset( $_POST['testimonials_nonce'] ) ) {
  		return;
	}
	
	if ( ! wp_verify_nonce( $_POST['testimonials_nonce'], 'testimonials_meta_box' ) ) {
  	return;
	}
	
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
  		return;
	}
	
	if ( ! isset( $_POST['testimonials_name'] ) || ! isset( $_POST['testimonials_company'] ) ) {
  	return;
	}
	
	$testimonials_name = sanitize_text_field( $_POST['testimonials_name'] );
	$testimonials_company = sanitize_text_field( $_POST['testimonials_company'] );

	update_post_meta( $post_id, '_testimonials_name', $testimonials_name );
	update_post_meta( $post_id, '_testimonials_company', $testimonials_company );

	if (!empty($_POST['custom_editor'])) {
    
        $data = $_POST['custom_editor'];
        update_post_meta($post_id, 'custom_editor', $data);
    }
   
}
add_action( 'save_post', 'save_testimonials' );

/* 
 * Display testimonials
 */ 
function makena_testimonials() { ?>

    <?php
    	global $post;
    		
        $args = array(
        	'post_type' => 'testimonials',
        	'posts_per_page' => 2,
        	'orderby' => 'rand'
        );
        	
        $testimonials = new WP_Query( $args ); ?>
     		 <?php  if ( $testimonials->have_posts() ) { ?>
     		 	<div class="grid-list testimonials">
              		<?php  while ( $testimonials->have_posts() ) { ?>
              			<div class="col-3">
           	 				<div class="featured-item">
                				<?php  $testimonials->the_post(); ?>
          							<?php the_post_thumbnail('thumbnail', array('class' => 'client-photo') ); ?>
            							<div class="testimonial-content">
            								<?php the_content(); ?>
            								<?php $name_value = get_post_meta(get_the_ID(), '_testimonials_name', true);
           	 								if (!empty($name_value)): ?>
                								<p class="client_name"><?php echo $name_value; ?></p>
           					 				<?php endif; ?>
            								<?php $company_value = get_post_meta(get_the_ID(), '_testimonials_company', true);
            								if (!empty($company_value)): ?>
                								<p class="company"><?php echo $company_value; ?></p>
                							<?php endif; ?>
                						</div><!-- /.testimonial-content -->
                			</div><!-- .featured-item -->
            			</div><!-- .col-3 -->
        		<?php }
        		
            		} else { ?>
            		
        			<?php } ?>
        			
        			<?php wp_reset_postdata();?>
        			
   				</div><!-- .grid-list.testimonials -->
	<?php 
}