<?php
/**
 * Theme customizer settings
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
 /**
 * Render the site title for the selective refresh partial.
 *
 * @since Makena 1.0
 * @see makena_customize_register()
 *
 * @return void
 */
function makena_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since Makena 1.0
 * @see makena_customize_register()
 *
 * @return void
 */
function makena_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Enqueue Javascript postMessage handlers for the Customizer.
 *
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since Makena 1.0
 */
function makena_customize_preview_js() {
	wp_enqueue_script( 'makena-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20141120', true );
}
add_action( 'customize_preview_init', 'makena_customize_preview_js' );
 
 /**
 * Register postMessage support.
 *
 * Add postMessage support for site title and description for the Customizer.
 *
 * @since Makena 1.0
 */
function makena_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector' => '.site-title > a',
			'container_inclusive' => false,
			'render_callback' => 'makena_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector' => '.site-description',
			'container_inclusive' => false,
			'render_callback' => 'makena_customize_partial_blogdescription',
		) );
	}
	
	// Add Section Title Panel on the Frontpage
		$wp_customize->add_panel( 'makena_theme_options', array(
	    	'priority' => 10,
	    	'capability' => 'edit_theme_options',
	    	'theme_supports' => '',
	    	'title' => esc_html__( 'Makena Theme Options', 'makena' ),
	    	'description' => __( 'Customize your theme.', 'makena' ),
		) );
		
	// Add Admin Login Logo Section
		$wp_customize->add_section(
			'cgg_admin_login_logo_section', array(
			'title'       => esc_html__( 'Admin Login Logo', 'makena' ),
			'capability'  => 'edit_theme_options',
			'panel' => 'makena_theme_options',
			)
		);

	// Add Admin Login Logo
		$wp_customize->add_setting( 'cgg_admin_login_logo', array(
    		'sanitize_callback' => 'esc_url_raw'
			)
		);
    	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'cgg_admin_login_logo',
			array(
				'label'   	 => esc_html__( 'Admin Login Logo ', 'makena' ),
				'section' 	 => 'cgg_admin_login_logo_section',
				'settings'   => 'cgg_admin_login_logo',
				) 
			)
		);
				
}
add_action( 'customize_register', 'makena_customize_register' );

/**
 * Change the Admin Login Logo
 *
 * @since Makena 1.3
 */
function cgg_theme_admin_login_logo() { ?>
    <style type="text/css">
        #login h1 a, .login h1 a {
        	background-image: url('<?php echo get_theme_mod( "cgg_admin_login_logo" );?>');
			width: 320px;
			background-size: 65%;
			background-repeat: no-repeat;
        }
    </style>
<?php }
add_action( 'login_enqueue_scripts', 'cgg_theme_admin_login_logo' );

function cgg_theme_login_logo_url() {
    return home_url();
}
add_filter( 'login_headerurl', 'cgg_theme_login_logo_url' );

function cgg_theme_login_logo_url_title() {
	$blog_title = get_bloginfo();
    return $blog_title;
}
add_filter( 'login_headertext', 'cgg_theme_login_logo_url_title' );
