<?php
/**
 * WooCommerce functions
 *
 * @package WordPress
 * @subpackage Makena
 * @since Makena 1.0
 */
 
/**
 * WOOCOMMERCE SUPPORT - Query whether WooCommerce is activated
 */
if ( ! function_exists( 'is_woocommerce_activated' ) ) {
	function is_woocommerce_activated() {
		if ( class_exists( 'woocommerce' ) ) { return true; } else { return false; }
	}
}

/**
 * Declare WooCommerce support in third party theme
 */
add_action( 'after_setup_theme', 'woocommerce_support' );
function woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

/*
 * Add Woocommerce styles
 */
function wp_enqueue_woocommerce_style(){
	wp_register_style( 'custom-woocommerce', get_template_directory_uri() . '/inc/woocommerce/woo-styles.css' );
	
	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style( 'custom-woocommerce' );
	}
}
add_action( 'wp_enqueue_scripts', 'wp_enqueue_woocommerce_style' );

/** 
 * Woocommerce theme's mark up Settings
 * 
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

add_action('woocommerce_before_main_content', 'custom_wrapper_start', 10);
add_action('woocommerce_after_main_content', 'custom_wrapper_end', 10);

function custom_wrapper_start() {
  		echo '<div id="primary" class="site-content"><div id="content" role="main">';
  		
}

function custom_wrapper_end() {
  		echo '</div></div>';
}

/**
 * Remove Add to cart button on product archive page
 */
 remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10);

/**
 * Remove The Shop Title
 */
 add_filter( 'woocommerce_show_page_title', '__return_false' );

/**
 * Alter The Archive Title for The Shop
 *
 * If your theme is using the archive_title() or get_archive_title() functions to display the title for your archives 
 * you can easily tweak it via a filter to grab the name of your product page instead for the shop archive title.
 *
 */
 function custom_woo_archive_title( $title ) {
	if ( is_shop() && $shop_id = wc_get_page_id( 'shop' ) ) {
		$title = get_the_title( $shop_id );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'custom_woo_archive_title' );

/**
 * Change number of thumbnails per row
 */
 
add_filter( 'woocommerce_single_product_image_gallery_classes', 'makena_5_columns_product_gallery' );
function makena_5_columns_product_gallery( $wrapper_classes ) {
	$columns = 5; // change this to 2, 3, 5, etc. Default is 4.
	$wrapper_classes[2] = 'woocommerce-product-gallery--columns-' . absint( $columns );
	return $wrapper_classes;
}

/** 
 * Display latest shop entries
 */
function recent_shop_entries() {
		
	// Get Child Pages from Database.
		$args = array( 
			'post_type' 		=> 'product', 
			'stock' 			=> 1, 
			'posts_per_page' 	=> 4, 
			'orderby' 			=>'date', 
			'order' 			=> 'DESC',
			'post_status'    	=> 'publish' 
		);
		
		$loop = new WP_Query( $args ); 

	// Check if there are child pages.
	if ( $loop->have_posts() ) : ?>
	<div class="col-6 shop-entries">
		<header class="section-header">
			<?php if ( get_theme_mod( 'makena_shop_entries_section_title', __( 'Latest Products', 'makena' ) ) ): ?>
				<h2 class="entry-title">
					<span><?php echo esc_html( get_theme_mod( 'makena_shop_entries_section_title', __( 'Latest Products', 'makena' ) ) ); ?></span>
				</h2>
			<?php endif; ?>
		</header>
		<div class="grid-list">
			<?php while ( $loop->have_posts() ) : $loop->the_post(); global $product; ?>
				<div class="col-product">
					<div class="featured-item">
						<a id="id-<?php the_id(); ?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
							<?php if (has_post_thumbnail( $loop->post->ID )) echo get_the_post_thumbnail($loop->post->ID, 'shop_catalog'); 
								else echo '<img src="'.woocommerce_placeholder_img_src().'" alt="My Image Placeholder" width="65px" height="115px" />'; ?>
						</a>
						<div class="product-content">
							<h5 class="product-title">
								<a id="id-<?php the_id(); ?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
									<?php the_title(); ?>
								</a>
							</h5>
							<div class="item-price"><span class="price"><?php echo $product->get_price_html(); ?></span></div>
						</div><!-- .product-content -->
						<div class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php woocommerce_template_loop_add_to_cart( $loop->post, $product ); ?></div>
					</div><!-- .featured-item -->
				</div><!-- .col-product -->
				<?php endwhile; ?>
		</div><!-- .grid-list -->
	   	<footer>
			<?php if ( get_theme_mod( 'makena_se_archive_link_text', __( 'More Products', 'makena' ) ) ): ?>
				<a class="moretag" href="<?php echo get_permalink( get_page_by_path( 'Shop' ) ) ?>">
					<?php echo esc_html( get_theme_mod( 'makena_se_archive_link_text', __( 'More Products', 'makena' ) ) ); ?>
				</a>
			<?php endif; ?>
		</footer>
	</div><!-- /.col-6.shop-entries -->
		<?php endif;
		//Reset Postdata.
	wp_reset_postdata();
}

/** 
 * Display featured shop entries
 */
function featured_shop_entries() {
		
	// Get Child Pages from Database.
		$args = array( 
		'post_type' 		=> 'product', 
		'stock' 			=> 1, 
		'posts_per_page' 	=> 4, 
		'orderby' 			=>'date', 
		'order' 			=> 'DESC',
		'post_status'    => 'publish',
		'tax_query'      => array(
			array(
				'taxonomy' => 'product_visibility',
				'field'    => 'name',
				'terms'    => 'featured',
				'operator' => 'IN',
			),
		)   
	);
		
		$featured_product = new WP_Query( $args ); 

	// Check if there are child pages.
	if ( $featured_product->have_posts() ) : ?>
	<div class="col-6 shop-entries">
		<header class="section-header">
			<?php if ( get_theme_mod( 'makena_featured_shop_entries_section_title', __( 'Featured Products', 'makena' ) ) ): ?>
				<h2 class="entry-title">
					<span><?php echo esc_html( get_theme_mod( 'makena_featured_shop_entries_section_title', __( 'Featured Products', 'makena' ) ) ); ?></span>
				</h2>
			<?php endif; ?>
		</header>
		
		<div class="grid-list">
			<?php while ( $featured_product->have_posts() ) : $featured_product->the_post(); global $product; ?>
				<div class="col-product">
					<div class="featured-item">
						<a id="id-<?php the_id(); ?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
							<?php if (has_post_thumbnail( $featured_product->post->ID )) echo get_the_post_thumbnail($featured_product->post->ID, 'shop_catalog'); 
								else echo '<img src="'.woocommerce_placeholder_img_src().'" alt="My Image Placeholder" width="65px" height="115px" />'; ?>
						</a>
						<div class="product-content">
							<h5 class="product-title">
								<a id="id-<?php the_id(); ?>" href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
									<?php the_title(); ?>
								</a>
							</h5>
							<div class="item-price"><span class="price"><?php echo $product->get_price_html(); ?></span></div>
						</div><!-- .item-content -->
						<div class="button product_type_simple add_to_cart_button ajax_add_to_cart"><?php woocommerce_template_loop_add_to_cart( $featured_product->post, $product ); ?></div>
					</div><!-- .featured-item -->
				</div><!-- .col-product -->
				<?php endwhile; ?>
		</div><!-- /.grid-list -->
	</div><!-- .col-6.shop-entries -->
		<?php endif;
		//Reset Postdata.
	wp_reset_postdata();
}
