/**
 * Handles toggling the navigation menu for small screens and
 * accessibility for submenu items.
 */
( function() {
	var nav = document.getElementById( 'site-navigation' ), button, menu;
	if ( ! nav ) {
		return;
	}

	button = nav.getElementsByTagName( 'button' )[0];
	menu   = nav.getElementsByTagName( 'ul' )[0];
	if ( ! button ) {
		return;
	}

	// Hide button if menu is missing or empty.
	if ( ! menu || ! menu.childNodes.length ) {
		button.style.display = 'none';
		return;
	}

	button.onclick = function() {
		if ( -1 === menu.className.indexOf( 'nav-menu' ) ) {
			menu.className = 'nav-menu';
		}

		if ( -1 !== button.className.indexOf( 'toggled-on' ) ) {
			button.className = button.className.replace( ' toggled-on', '' );
			menu.className = menu.className.replace( ' toggled-on', '' );
		} else {
			button.className += ' toggled-on';
			menu.className += ' toggled-on';
		}
	};
} )();

// Better focus for hidden submenu items for accessibility.
( function( $ ) {
	$( '.main-navigation' ).find( 'a' ).on( 'focus.makena blur.makena', function() {
		$( this ).parents( '.menu-item, .page_item' ).toggleClass( 'focus' );
	} );

  if ( 'ontouchstart' in window ) {
    $('body').on( 'touchstart.makena',  '.menu-item-has-children > a, .page_item_has_children > a', function( e ) {
      var el = $( this ).parent( 'li' );

      if ( ! el.hasClass( 'focus' ) ) {
        e.preventDefault();
        el.toggleClass( 'focus' );
        el.siblings( '.focus').removeClass( 'focus' );
      }
    } );
  }
} )( jQuery );

/**
 * Display sub-menu on click
 */
( function( $ ) {
	 $('.menu-item-has-children > a, .page_item_has_children > a').click(function(){
    	$('ul.sub-menu').slideToggle('fast');
  });
} )( jQuery );


/**
 * Scroll to Top JS
 *
 * Source: https://themecoder.de/2017/09/29/wordpress-scroll-to-top-button-mit-jquery-realisieren/
 */

( function( $ ) {

	$.fn.scrollToTop = function() {

		var scrollButton = $( this );

		/* Hide Button by default */
		scrollButton.hide();

		/* Show Button on scroll down */
		var showButton = function() {

			var window_top = $( window ).scrollTop();

			if ( window_top > 150 ) {
				scrollButton.fadeIn( 200 );
			} else {
				scrollButton.fadeOut( 200 );
			}
		}

		showButton();
		$( window ).scroll( showButton );

		/* Scroll back to top when element is clicked */
		scrollButton.click( function () {
			$( 'html, body' ).animate( { scrollTop: 0 }, 300 );
			return false;
		} );

	};

	$( document ).ready( function() {

		/* Add Button to HTML DOM */
		$( 'body' ).append( '<button id=\"scroll-to-top\" class=\"scroll-to-top-button\"></button>' );

		/* Add Scroll To Top Functionality */
		$( '#scroll-to-top' ).scrollToTop();

	} );

} ( jQuery ) );

